@@ -2,6 +2,7 @@ from abc import abstractmethod
 
 from api.handler import HandlerEnum
 from api.handler.IHandler import IHandler
+from api.handler.IRevoke import IRevoke
 from api.handler.script.ICacheAbleScript import ICacheAbleScript
 from api.handler.IKillable import IKillable
 from api.handler.ILogAbleHandler import ILogAbleHandler
@@ -9,7 +10,7 @@ from api.handler.script.IProgressAbleScript import IProgressAbleScript
 from api.model.FdInputPipe import FdInputPipe
 
 
-class ISimpleScriptCE(IKillable, ILogAbleHandler, ICacheAbleScript, IHandler, IProgressAbleScript):
+class ISimpleScriptCE(IKillable, ILogAbleHandler, ICacheAbleScript, IHandler, IProgressAbleScript, IRevoke):
     """
     Python脚本式的CE的基类
     """
