@@ -147,6 +147,10 @@ def init_profile_from_environ_property():
         config.work_on_k8s = bool(environs["WORK_ON_K8S"])
         log.info(f"从系统环境变量中获取到WORK_ON_K8S:{config.work_on_k8s}")
 
+    if "K8S_AUTH_SERVER_SERVICE" in environs:
+        config.k8s_auth_server_service = environs["K8S_AUTH_SERVER_SERVICE"]
+        log.info(f"从系统环境变量中获取到K8S_AUTH_SERVER_SERVICE:{config.k8s_auth_server_service}")
+
     if "K8S_CONFIG_SERVER_SERVICE" in environs:
         config.k8s_config_server_service = environs["K8S_CONFIG_SERVER_SERVICE"]
         log.info(f"从系统环境变量中获取到K8S_CONFIG_SERVER_SERVICE:{config.k8s_config_server_service}")
