@@ -267,7 +267,7 @@ class TaskThread(threading.Thread):
         try:
             if task_param is None:
                 # 没有任务
-                return
+                return FAIL
 
             log_id = task_param.logId
 
@@ -287,6 +287,17 @@ class TaskThread(threading.Thread):
                                                  f"{config.server_ip or config.find_host_ip()}:{config.server_port or 5000}",
                                                  1)
 
+            # 这里再判断一下ProcessLogId所对应的状态,有可能已经是失败了,那么这个任务也就不要做了
+            if task_param.processLogId is not None:
+                # 说明是有ProcessLogId的
+                process_log = client.ScheduleJobTaskLogClient.get_task_log_by_id(task_param.processLogId)
+                if process_log is not None and process_log.executeStatus == -1:
+                    # 说明主的流程任务已经失败了,这个任务不用执行了
+                    err = f"logId:{log_id}的任务,因为主任务:{task_param.processLogId}状态为-1,不继续执行"
+                    FrameworkHandlerLogger.log_info(err)
+                    self.__update_task_status_to_finished(log_id, ResultVO(FAIL_CODE, err), False, 1)
+                    return ResultVO(FAIL_CODE, err)
+
             from schedule import ShardContext
             try:
                 from schedule.ShardContext import Sharding
